This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html). Upgrades from major to major versions, such a change from version `5.6.0` to `6.0.0`, might require local configuration updates to ensure compatibility with your current scripts. Make sure you have the latest version of the SDK using `pip install -U cortex-python`.

## [6.1.0] - 2021-11-18
### Added

- Support for Model CRUD methods
- Configurable artifact key for loading a Model from an Experiment
- Support for creating Experiments using Model
